@@ -16,17 +16,19 @@
 """Fixtures used during Gabbi-based test runs."""
 
 import os
+import unittest
+from unittest import mock
 
 from gabbi import fixture
-import mock
 from oslo_config import cfg
 from oslo_config import fixture as fixture_config
 from oslo_policy import opts
 from oslo_utils import uuidutils
-from six.moves.urllib import parse as urlparse
 import sqlalchemy_utils
+from urllib import parse as urlparse
 
 from aodh.api import app
+from aodh.api import rbac
 from aodh import service
 from aodh import storage
 
@@ -59,7 +61,8 @@ class ConfigFixture(fixture.GabbiFixture):
             'AODH_TEST_STORAGE_URL', "").replace(
                 "mysql://", "mysql+pymysql://")
         if not db_url:
-            self.fail('No database connection configured')
+            raise unittest.TestCase.failureException(
+                'No database connection configured')
 
         conf = service.prepare_service([], config_files=[])
         # NOTE(jd): prepare_service() is called twice: first by load_app() for
@@ -76,10 +79,7 @@ class ConfigFixture(fixture.GabbiFixture):
         self.conf = conf
         opts.set_defaults(self.conf)
 
-        conf.set_override('policy_file',
-                          os.path.abspath(
-                              'aodh/tests/open-policy.json'),
-                          group='oslo_policy')
+        rbac.enforce = mock.Mock()
         conf.set_override('auth_mode', None, group='api')
 
         parsed_url = urlparse.urlparse(db_url)
