@@ -15,7 +15,8 @@
 # under the License.
 """Tests for aodh/storage/
 """
-import mock
+from unittest import mock
+
 from oslo_config import fixture as fixture_config
 from oslotest import base
 
@@ -23,8 +24,6 @@ from aodh import service
 from aodh import storage
 from aodh.storage import impl_log
 
-import six
-
 
 class EngineTest(base.BaseTestCase):
     def setUp(self):
@@ -45,7 +44,7 @@ class EngineTest(base.BaseTestCase):
         try:
             storage.get_connection_from_config(self.CONF)
         except RuntimeError as err:
-            self.assertIn('no-such-engine', six.text_type(err))
+            self.assertIn('no-such-engine', str(err))
 
 
 class ConnectionRetryTest(base.BaseTestCase):
