@@ -244,7 +244,8 @@ function install_aodh {
     else
         PY_VERS=${PYTHON2_VERSION}
     fi
-    sudo -H python${PY_VERS} -m pip install -e "$AODH_DIR"[test,$AODH_BACKEND]
+    sudo -H SETUPTOOLS_USE_DISTUTILS=stdlib python${PY_VERS} -m pip \
+	    install -e "$AODH_DIR"[test,$AODH_BACKEND]
     sudo install -d -o $STACK_USER -m 755 $AODH_CONF_DIR
 
     if [ "$AODH_DEPLOY" == "mod_wsgi" ]; then
@@ -270,8 +271,6 @@ function start_aodh {
     if [[ "$AODH_DEPLOY" == "mod_wsgi" ]]; then
         enable_apache_site aodh
         restart_apache_server
-        tail_log aodh /var/log/$APACHE_NAME/aodh.log
-        tail_log aodh-api /var/log/$APACHE_NAME/aodh_access.log
     elif [ "$AODH_DEPLOY" == "uwsgi" ]; then
         run_process aodh-api "$AODH_BIN_DIR/uwsgi $AODH_UWSGI_FILE"
     else
